unit mynavigator;

{$mode ObjFPC}{$H+}

interface

uses
  Buttons, Classes, StdCtrls, SysUtils, Forms, Controls, Dialogs,
  db;

type
  TMyDBNavigatorFrame = class(TFrame)
    ImageList1: TImageList;
    btnFirst: TSpeedButton;
    btnPrior: TSpeedButton;
    btnNext: TSpeedButton;
    btnLast: TSpeedButton;
    Label1: TLabel;
    btnAdd: TSpeedButton;
    btnDelete: TSpeedButton;
    btnPost: TSpeedButton;
    btnCancel: TSpeedButton;
    procedure btnCancelClick(Sender: TObject);
    procedure btnFirstClick(Sender: TObject);
    procedure btnLastClick(Sender: TObject);
    procedure btnNextClick(Sender: TObject);
    procedure btnPostClick(Sender: TObject);
    procedure btnPriorClick(Sender: TObject);
    procedure btnAddClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
  private
    FDataset: TDataset;
    procedure SetDataset(AValue: TDataset);
  protected

  public
    constructor Create(AOwner: TComponent); override;
    procedure UpdateBtns;
    property Dataset: TDataset read FDataset write SetDataset;

  end;

implementation

{$R *.lfm}

constructor TMyDBNavigatorFrame.Create(AOwner: TComponent);
begin
  inherited;
  UpdateBtns;
end;

procedure TMyDBNavigatorFrame.btnFirstClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.First;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnCancelClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Cancel;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnLastClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Last;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnNextClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Next;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnPostClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Post;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnPriorClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Prior;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnAddClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    FDataset.Insert;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.btnDeleteClick(Sender: TObject);
begin
  if FDataset <> nil then
  begin
    if MessageDlg('Soll dieser Datensatz wirklich gelöscht werden?', mtConfirmation, [mbYes, mbNo], 0) = mrYes then
    begin
      FDataset.Delete;
      UpdateBtns;
    end;
  end;
end;

procedure TMyDBNavigatorFrame.SetDataset(AValue: TDataset);
begin
  if AValue <> FDataset then
  begin
    FDataset := AValue;
    UpdateBtns;
  end;
end;

procedure TMyDBNavigatorFrame.UpdateBtns;
var
  isEditing: Boolean;
begin
  isEditing := (FDataset <> nil) and (FDataset.State in dsEditModes);
  btnFirst.Enabled := (FDataset <> nil) and (not FDataset.BOF) and (not isEditing);
  btnPrior.Enabled := (FDataset <> nil) and (not FDataset.BOF) and (not isEditing);
  btnNext.Enabled := (FDataset <> nil) and (not FDataset.EOF) and (not isEditing);
  btnLast.Enabled := (FDataset <> nil) and (not FDataset.EOF) and (not isEditing);
  btnAdd.Enabled := (FDataset <> nil) and (not isEditing);
  btnDelete.Enabled := (FDataset <> nil) and not (FDataset.EOF and Dataset.BOF) and (not isediting);
  btnPost.Enabled := isEditing;
  btnCancel.Enabled := isEditing;
end;

end.

